==> qtjambi-quick-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiQuick/QQuickCloseEvent_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/private/qquickevents_p_p.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// destruct QQuickCloseEvent
void __qt_destruct_QQuickCloseEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQuickCloseEvent")
    reinterpret_cast<QQuickCloseEvent*>(ptr)->~QQuickCloseEvent();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQuickCloseEvent::isAccepted()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_internal_QQuickCloseEvent_isAccepted_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QQuickCloseEvent *__qt_this = QtJambiAPI::objectFromNativeId<QQuickCloseEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickCloseEvent::isAccepted()", __this_nativeId)
        __java_return_value = __qt_this->isAccepted();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQuickCloseEvent::setAccepted(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_internal_QQuickCloseEvent_setAccepted_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean accepted0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QQuickCloseEvent *__qt_this = QtJambiAPI::objectFromNativeId<QQuickCloseEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickCloseEvent::setAccepted(bool)", __this_nativeId)
        __qt_this->setAccepted(static_cast<bool>(accepted0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQuickCloseEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QQuickCloseEvent>("QQuickCloseEvent", "io/qt/quick/internal/QQuickCloseEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQuickCloseEvent, {
    });
// END: function table

    registerMetaObject(typeId, QQuickCloseEvent::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiQuick/QQuickCloseEvent_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/6.6.0/QtQuick/private/qquickevents_p_p.h>
#include <QtCore/QVariant>
#include <QtCore/QList>
#include <QtCore/qobject.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qtimer.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qvariant.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qthread.h>
#include <QtCore/qproperty.h>
#include <QtCore/qbindingstorage.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// destruct QQuickCloseEvent
void __qt_destruct_QQuickCloseEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQuickCloseEvent")
    reinterpret_cast<QQuickCloseEvent*>(ptr)->~QQuickCloseEvent();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQuickCloseEvent::isAccepted()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_internal_QQuickCloseEvent_isAccepted_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QQuickCloseEvent *__qt_this = QtJambiAPI::objectFromNativeId<QQuickCloseEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickCloseEvent::isAccepted()", __qt_this)
        __java_return_value = __qt_this->isAccepted();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQuickCloseEvent::setAccepted(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_internal_QQuickCloseEvent_setAccepted_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean accepted0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QQuickCloseEvent *__qt_this = QtJambiAPI::objectFromNativeId<QQuickCloseEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickCloseEvent::setAccepted(bool)", __qt_this)
        __qt_this->setAccepted(static_cast<bool>(accepted0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQuickCloseEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QQuickCloseEvent>("QQuickCloseEvent", "io/qt/quick/internal/QQuickCloseEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQuickCloseEvent, {
    });
// END: function table

    registerMetaObject(typeId, QQuickCloseEvent::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
